@@ -8,6 +8,12 @@ use swc_ecma_visit::{noop_visit_mut_type, VisitMut};
 
 pub(crate) mod fast_graph;
 
+#[cfg(feature = "concurrent")]
+pub(crate) type Readonly<T> = std::sync::Arc<T>;
+
+#[cfg(not(feature = "concurrent"))]
+pub(crate) type Readonly<T> = T;
+
 const TRACK: bool = false;
 
 pub(crate) trait VarDeclaratorExt: Into<VarDeclarator> {
